@@ -11,7 +11,7 @@ from google.protobuf import json_format
 from google.protobuf.message import Message
 
 # IMPORTATION INTERNAL
-import degiro_connector.core.constants.urls as urls
+from degiro_connector.core.constants import urls
 from degiro_connector.quotecast.models.quotecast_pb2 import (
     Chart,
 )
@@ -303,7 +303,7 @@ class ActionGetChart(AbstractAction):
         response_raw = None
 
         try:
-            response_raw = session.send(prepped, verify=False)
+            response_raw = session.send(prepped)
             response_raw.raise_for_status()
             response_dict = json.loads(response_raw.text[len(cls.CALLBACK) + 1 : -1])
 
