@@ -5,7 +5,7 @@ from typing import Optional
 
 # IMPORTATION THIRD PARTY
 # IMPORTATION INTERNAL
-import degiro_connector.core.constants.urls as urls
+from degiro_connector.core.constants import urls
 from degiro_connector.quotecast.models.quotecast_pb2 import (
     Quotecast,
 )
@@ -84,7 +84,7 @@ class ActionSubscribe(AbstractAction):
         response_raw = None
 
         try:
-            response_raw = session.send(request=prepped, verify=False)
+            response_raw = session.send(request=prepped)
             response_raw.raise_for_status()
 
             if response_raw.text == '[{"m":"sr"}]':
