@@ -6,7 +6,7 @@ from typing import Dict, Union
 # IMPORTATION THIRD PARTY
 
 # IMPORTATION INTERNAL
-import degiro_connector.core.constants.urls as urls
+from degiro_connector.core.constants import urls
 from degiro_connector.trading.models.trading_pb2 import (
     Credentials,
     Order,
@@ -225,7 +225,7 @@ class ActionGetUpdate(AbstractAction):
         response_raw = None
 
         try:
-            response_raw = session.send(prepped, verify=False)
+            response_raw = session.send(prepped)
             response_raw.raise_for_status()
             response_dict = response_raw.json()
 
